# 15 Metro: Step-by-Step Code Overview

This gives a step-by-step overview of what the code 
in this repository is trying to accomplish.

More on the object-oriented design and implementation
of these steps here: [OODesign.md](OODesign.md)

## Step 1: Data Ingestion

More details on how this is implemented [at Step1.md](Step1.md)


### Step 1A: Extracting Census Data

This step uses the Census Reporter API to interface with the data,
extract relevant tables and quantities, process it (compute any 
convenient, basic derived quantities).


### Step 1B: JSON Storage and Access

This involes setting up the JSON to be in a MongoDB 
(alternatively, could dump the data to an Amazon S3 bucket).

In our previous Shrubbery projects, this step was 
simply cut out, and we skipped straight to making 
the D3 + Leaflet map. But this process is a bit 
different. Here, we're dealing with a much larger
dataset, and we are performing a more in-depth 
statistical analysis of the data.

We need flexibility: 
we need to be able to slice and dice the data,
crunch numbers in parallel, 
and expand the available data
to include these calculated quantities
(and/or orthogonal datasets 
that are not spatial in nature).


## Step 2: Analysis and Modeling

More details on how this is implemented [at Step2.md](Step2.md)

Once we have extracted the relevant data and have stored it in our database,
we can use it in some heavy-duty analysis scripts. 

We will start by writing these analysis scripts for a single metropolitan area,
and perfecting it for generating new data for the database (data which we will
plot with D3.js and Leaflet.js).

Next, we will parallelize the algorithm and turn it loose on the entire set of 
15 (or more) metropolitan areas.

## Step 3: Visualization

The last step is to incorporate the data and analysis results 
into a visualization that is interactive and that can be used
to explore the many dimensions of the dataset.

This step uses D3.js, Leaflet.js, and Angular.js to build a 
frontend user interface for visualizing data.

