import numpy as np
import pandas as pd

import matplotlib.pyplot as plt
import seaborn as sns

import statsmodels.api as sm
from scipy import stats

import metro as mt

def main():
    do_15002()

def do_15002():

    from Table15002 import Table15002

    # Seaborn 
    sns.set_palette("deep", desat=.6)
    sns.set_context(rc={"figure.figsize": (8, 4)})
    
    for city in cities:

        mogo = mt.MetroMogo()
        df = mogo.get_df(city,tablecode="B15002")

        df = Table15002(df)

        #######################
        # Scatter plot:
        #
        # average vs variance 
        # average vs gender imbalance
    
        f, (ax1, ax2) = plt.subplots(2, 1, sharex=True, figsize=(8, 8))
    
        colors = ["windows blue", 
                  "dusty purple", 
                  "faded green", 
                  "amber"]
        xcp = sns.xkcd_palette(colors)

        # ------------------------
        # Subplot 1
    
        ax1.set_title(cities[0])
    
        xcode = 'AvgEd'
        xlabel=xcode

        ycode = 'VarEd_M'
        ylabel=ycode
        sns.regplot(df[xcode],df[ycode], color=xcp[0], ax=ax1, fit_reg=False)

        ycode = 'VarEd_F'
        ylabel=ycode
        sns.regplot(df[xcode],df[ycode], color=xcp[2], ax=ax1, fit_reg=False)
    
        xlim = (min(df[xcode]),
                max(df[xcode]))
        ylim = (min(df[ycode]),
                max(df[ycode]))
    
        ax1.set_xlim(xlim)
        ax1.set_ylim(ylim)
    
        ax1.set_xlabel(xlabel)
        ax1.set_ylabel(ylabel)


        # ------------------------
        # Subplot 2
    
        xcode = 'AvgEd'
        xlabel=xcode
        ycode = 'EdGenderImbalance'
        ylabel=ycode
        df2 = df[df[xcode]>0]
        sns.regplot(df2[xcode],df2[ycode], color=xcp[3], ax=ax2, fit_reg=False)
    
        xlim = (min(df2[xcode]),
                max(df2[xcode]))
        ylim = (min(df2[ycode]),
                max(df2[ycode]))
    
        ax2.set_xlim(xlim)
        ax2.set_ylim(ylim)
    
        ax2.set_xlabel(xlabel)
        ax2.set_ylabel(ylabel)



        #######################
        # Scatter plot:
        # 
        # variances vs averages
        # variances vs gender imbalance
    
        f, (ax1, ax2) = plt.subplots(2, 1, sharex=True, figsize=(8, 8))
    
        colors = ["taupe",
                  "pale red",
                  "steel"]
        xcp = sns.xkcd_palette(colors)

        # ------------------------
        # Subplot 1
    
        ax1.set_title(cities[0])
    
        xcode = 'VarEd_M'
        xlabel=xcode
        ycode = 'AvgEd_M'
        ylabel=ycode
        df2 = df[df[xcode]>0]
        sns.regplot(df2[xcode],df2[ycode], color=xcp[0], ax=ax1, fit_reg=False)
    
        xcode = 'VarEd_F'
        xlabel=xcode
        ycode = 'AvgEd_F'
        ylabel=ycode
        df2 = df[df[xcode]>0]
        sns.regplot(df2[xcode],df2[ycode], color=xcp[1], ax=ax1, fit_reg=False)
    
        xcode = 'VarEd'
        xlabel=xcode
        ycode = 'AvgEd'
        ylabel=ycode
        df2 = df[df[xcode]>0]
        sns.regplot(df2[xcode],df2[ycode], color=xcp[2], ax=ax1, fit_reg=False)
    


        # ------------------------
        # Subplot 2
    
        ax1.set_title(cities[0])
    
        xcode = 'VarEd_M'
        xlabel=xcode
        ycode = 'EdGenderImbalance'
        ylabel=ycode
        df2 = df[df[xcode]>0]
        sns.regplot(df2[xcode],df2[ycode], color=xcp[0], ax=ax2, fit_reg=False)

        xcode = 'VarEd_F'
        xlabel=xcode
        ycode = 'EdGenderImbalance'
        ylabel=ycode
        df2 = df[df[xcode]>0]
        sns.regplot(df2[xcode],df2[ycode], color=xcp[1], ax=ax2, fit_reg=False)

        xcode = 'VarEd'
        xlabel=xcode
        ycode = 'EdGenderImbalance'
        ylabel=ycode
        df2 = df[df[xcode]>0]
        sns.regplot(df2[xcode],df2[ycode], color=xcp[2], ax=ax2, fit_reg=False)


        plt.show()


cities = ['San Francisco']

if __name__=="__main__":
    main()

