from pymongo import MongoClient

import numpy as np
import pandas as pd

import matplotlib.pyplot as plt
import seaborn as sns

import statsmodels.api as sm
from scipy import stats

import metro as mt

def main():
    do_17001()

def do_17001():

    from Table17001 import Table17001
    
    # Seaborn 
    sns.set_palette("deep", desat=.6)
    sns.set_context(rc={"figure.figsize": (8, 4)})
    c1, c2, c3 = sns.color_palette("Set1", 3)
    
    for city in cities:
    
        mogo = mt.MetroMogo()
        df = mogo.get_df(city,tablecode="B17001")

        df = Table17001(df)
    
        #######################
        # Scatter plots:
        #
        # Total population vs male/female poverty rate
        # Total population vs male/female senior poverty rate
    
        f, (ax1, ax2) = plt.subplots(2, 1, sharex=True, figsize=(8, 8))
    
        # ------------------------
        # Subplot 1
    
        ax1.set_title(cities[0])
    
        xcode = 'TotalPop'
        xlabel=xcode
        ycode = 'M_P_PctM'
        ylabel=ycode
        sns.regplot(df[xcode],df[ycode], color=c2, ax=ax1, fit_reg=False)
    
        xcode = 'TotalPop'
        xlabel=xcode
        ycode = 'F_P_PctF'
        ylabel=ycode
        sns.regplot(df[xcode],df[ycode], color=c1, ax=ax1, fit_reg=False)
    
        xlim = (min(df[xcode]),
                max(df[xcode]))
        ylim = (min(df[ycode]),
                max(df[ycode]))
    
        ax1.set_xlim(xlim)
        ax1.set_ylim(ylim)
    
        ax1.set_xlabel(xlabel)
        ax1.set_ylabel('Pct Population Below Pov Line')
    
        # ------------------------
        # Subplot 2
    
        xcode = 'TotalPop'
        xlabel=xcode
        ycode = 'SrM_P_PctM'
        ylabel=ycode
        sns.regplot(df[xcode],df[ycode], color=c2, ax=ax2, fit_reg=False)
    
        xcode = 'TotalPop'
        xlabel=xcode
        ycode = 'SrF_P_PctF'
        ylabel=ycode
        sns.regplot(df[xcode],df[ycode], color=c1, ax=ax2, fit_reg=False)
    
        xlim = (min(df[xcode]),
                max(df[xcode]))
        ylim = (min(df[ycode]),
                max(df[ycode]))
    
        ax2.set_xlim(xlim)
        ax2.set_ylim(ylim)
    
        ax2.set_xlabel(xlabel)
        ax2.set_ylabel('Pct Seniors Below Pov Line')




        #######################
        # Plot:
        # Percent of people in poverty
        # overall, and by gender
        
        f, (ax1, ax2) = plt.subplots(2, 1, sharex=True, figsize=(8, 8))
        sns.kdeplot(df['P_Pct'],    shade=True, color=c3, ax=ax1)
        sns.kdeplot(df['M_P_PctM'], shade=True, color=c2, ax=ax2)
        sns.kdeplot(df['F_P_PctF'], shade=True, color=c1, ax=ax2)
        
        ax1.set_xlim([0,1])
        ax2.set_xlim([0,1])

        ax1.set_xlabel('Pct Population Below Pov. Line')
        ax1.set_ylabel('Probability Density')
            
    

        #######################
        # Plot:
        # Pre-adolescent poverty levels 
        # (overall and by gender)
    
        xlim = 0.50
        ylim = 5
    
        f, (ax1, ax2) = plt.subplots(2, 1, sharex=True, figsize=(8, 8))
        sns.kdeplot( df['PAP_Pct'],    shade=True, color=c3, ax=ax1)
        sns.kdeplot( df['PAM_P_PctM'], shade=True, color=c2, ax=ax2)
        sns.kdeplot( df['PAF_P_PctF'], shade=True, color=c1, ax=ax2)
        
        ax1.set_xlim([0,1])
        ax2.set_xlim([0,1])

        ax1.set_xlabel('Pct Pre-Adolescents Below Pov. Line')
        ax1.set_ylabel('Probability Density')
        
        #f.savefig("onecity_univariate_"+city+"_2.jpg")
    
    
        #######################
        # Plot:
        # Senior poverty levels 
        # (overall and by gender)
    
        f, (ax1, ax2) = plt.subplots(2, 1, sharex=True, figsize=(8, 8))
        #ax1.set_title(cities[0] + " " + cities[1] + "Seniors")
        sns.kdeplot( df['SrP_Pct'],    shade=True, color=c3, ax=ax1)
        sns.kdeplot( df['SrM_P_PctM'], shade=True, color=c2, ax=ax2)
        sns.kdeplot( df['SrF_P_PctF'], shade=True, color=c1, ax=ax2)
    
        ax1.set_xlim([0,1])
        ax2.set_xlim([0,1])
    
        ax1.set_xlabel('Pct Seniors Below Pov. Line')
        ax1.set_ylabel('Probability Density')





cities = ['Seattle']

if __name__=="__main__":
    main()


