import numpy as np
import pandas as pd

import matplotlib.pyplot as plt
import seaborn as sns

import statsmodels.api as sm
from scipy import stats

import metro as mt

def main():
    do_25070()

def do_25070():

    from Table25070 import Table25070

    # Seaborn 
    sns.set_palette("deep", desat=.6)
    sns.set_context(rc={"figure.figsize": (8, 4)})

    for city in cities:

        mogo = mt.MetroMogo()
        df = mogo.get_df(city,tablecode="B25070")

        df = Table25070(df)

        #######################
        # Bar plot:
        #
        # Rent as percent of income
    
        f, ax1 = plt.subplots(1, 1, sharex=True, figsize=(12, 6))

        # ------------------------
        # Subplot 1
    
        ax1.set_title(cities[0])

        labels = ["0-10","10-15","15-20","20-25","25-30","30-35","35-40","40-50","50+"]
    
        ddt = {}
        for i,collab in enumerate(labels):
            lab = "Rent_"+collab+"_Pct"
            ddt[lab] = df[lab].values

        xx = np.array(ddt.keys())
        yy = np.array(ddt.values())
        sns.barplot(xx,yy,palette="Set1",ax=ax1)

        ax1.set_xlabel('Rent as Pct of Income')
        ax1.set_ylabel('Pct of Population')




        #######################
        # univariate KDE
        # 
        # density of (rent as pct of income) categories
    
        f, ax1 = plt.subplots(1, 1, sharex=True, figsize=(12, 6))
    
        # ------------------------
        # Subplot 1
    
        ax1.set_title(cities[0])

        labels = ["0-10","10-15","15-20","20-25","25-30","30-35","35-40","40-50","50+"]
        colpal = sns.color_palette("GnBu_d",len(labels))

        ddt = {}
        for i,lab in enumerate(labels):
            tlab = "Rent_"+lab+"_Pct"
            sns.kdeplot(df[tlab], shade=True, color=colpal[i], ax=ax1)
        ax1.set_xlim([0.001,1.0])

        ax1.set_xlabel('Percent of Population in Category')
        ax1.set_ylabel('Probability Density')


        #######################
        # joint KDE
        # 
        # joint density of 
        # (rent 10-15% of income) 
        # (rent 40-50% of income)

        #f, ax1 = plt.subplots(1, 1, sharex=True, figsize=(12, 6))

        #ax1.set_title(cities[0])

        #cmap = sns.cubehelix_palette(8, start=0.5, rot=-.75, as_cmap=True)
        #tlab1 = "Rent_10-15_Pct"
        #tlab2 = "Rent_40-50_Pct"
        #sns.kdeplot(df[tlab1], df[tlab2], shade=True, cmap=cmap, ax=ax1)



        #######################
        # pair grid 
        # multivariate whiz-bang plot
        # 
        # joint scatterplots
        # univariate kdes 
        # joint kdes
        # (x/y limits default to -3, +3)

        #columnlabels = ["Rent_%s_Pct"%(lab) for lab in labels]
        #cmap = sns.cubehelix_palette(8, start=0.5, rot=-.75, as_cmap=True)
        #g = sns.PairGrid(df[columnlabels], diag_sharey=False)
        #g.map_lower(sns.kdeplot, cmap=cmap)
        #g.map_upper(plt.scatter)
        #g.map_diag(sns.kdeplot, lw=2)



        ##########################
        # pair grid
        # 
        # grouped to have fewer variables 

        #new_labels = ["0-10","10-20","20-30","30-40","40-50","50+"]
        #colpal = sns.color_palette("GnBu_d",len(new_labels))
        #columnlabels = ["NewRent_%s_Pct"%(lab) for lab in new_labels]
        #cmap = sns.cubehelix_palette(8, start=0.5, rot=-.75, as_cmap=True)
        #g = sns.PairGrid(df[columnlabels], diag_sharey=False)
        #g.map_lower(sns.kdeplot, cmap=cmap)
        #g.map_upper(plt.scatter)
        #g.map_diag(sns.kdeplot, lw=2)


        plt.show()


cities = ['Seattle']

if __name__=="__main__":
    main()

