import numpy as np
import pandas as pd

import matplotlib.pyplot as plt
from matplotlib.ticker import FuncFormatter
import seaborn as sns

import statsmodels.api as sm
from scipy import stats

import metro as mt

def main():
    do_13016()

def do_13016():

    from Table13016 import Table13016
    from Table15002 import Table15002
    from Table19301 import Table19301

    # Seaborn 
    sns.set_palette("deep", desat=.6)
    sns.set_context(rc={"figure.figsize": (8, 4)})
    
    for city in cities:

        mogo = mt.MetroMogo()
        df = mogo.get_df(city,tablecode="B13016")

        df = Table13016(df)
        df = Table15002(df)
        df = Table19301(df)


        #######################
        # KDE plot:
        #
        # avg birth rate,
        # var birth rate

        f, ax1 = plt.subplots(1, 1, sharex=False, figsize=(8, 6))
        ax1.set_title(cities[0])

        colors = ["windows blue", 
                  "dusty purple", 
                  "faded green", 
                  "amber"]
        xcp = sns.xkcd_palette(colors)

        # ------------
        # Subplot 1

        xcode = 'BirthRateAvg'
        xlabel=xcode
        df2 = df[df[xcode]>0]
        sns.kdeplot(df2[xcode], shade=True, color=xcp[3], ax=ax1)

        # ------------
        # Subplot 2

        xcode = 'BirthRateVariance'
        xlabel=xcode
        df2 = df[df[xcode]>0]
        sns.kdeplot(df2[xcode], shade=True, color=xcp[1], ax=ax1)
        ax1.set_xlim([0,1.0])

        ax1.set_xlabel("Birth Rate Avg/Variance")
        ax1.set_ylabel("Probability Density")



        #######################
        # Scatter plot:
        #
        # (y) birth rate vs 
        # (x) average female education level
        #
        # (y) birth rate vs
        # (x) gender imbalance in avg education level

        f, (ax1, ax2) = plt.subplots(2, 1, sharex=False, figsize=(8, 8))

        ax1.set_title(cities[0])

        colors = ["reddish", 
                  "dark periwinkle",
                  "marigold",
                  "ocean"]
        xcp = sns.xkcd_palette(colors)
    
        # ----------------
        # Subplot 1

        xcode = 'AvgEd'
        xlabel=xcode

        ycode = 'BirthRateAvg'
        ylabel=ycode

        df2 = df[df[ycode]>0]

        sns.regplot(df2[xcode],df2[ycode], color=xcp[2], ax=ax1, fit_reg=False)

        ax1.set_xlabel("Education Level Avg")
        ax1.set_ylabel("Birth Rate Avg")

        # ----------------
        # Subplot 2

        xcode = 'EdGenderImbalance'
        xlabel=xcode

        ycode = 'BirthRateAvg'
        ylabel=ycode

        df2 = df[df[ycode]>0]

        sns.regplot(df2[xcode],df2[ycode], color=xcp[3], ax=ax2, fit_reg=False)

        ax2.set_xlabel("Gender Imbalance in Education Lvls")
        ax2.set_ylabel("Birth Rate Avg")



        #######################
        # Scatter plot:
        #
        # (y) birth rate vs 
        # (x) income per capita
        #
        # (y) birth rate vs
        # (x) gender imbalance in avg education level

        f, ax1 = plt.subplots(1, 1, sharex=False, figsize=(8, 6))

        ax1.set_title(cities[0])

        colors = ["reddish", 
                  "dark periwinkle",
                  "marigold",
                  "ocean"]
        xcp = sns.xkcd_palette(colors)

        # ------------
        # Subplot 1

        xcode = 'PerCapitaIncome'
        xlabel=xcode

        ycode = 'BirthRateAvg'
        ylabel=ycode

        df2 = df[df[ycode]>0]

        def thousands(x, pos):
            'The two args are the value and tick position'
            return '$%1.0fk' % (x*1e-3)

        fmt = FuncFormatter(thousands)
        ax1.set_xlim([0,100000])
        ax1.set_ylim([0,0.25])
        ax1.xaxis.set_major_formatter(fmt)
        sns.regplot(df2[xcode],df2[ycode], color=xcp[0], ax=ax1, fit_reg=False)

        ax1.set_xlabel("Per Capita Income")
        ax1.set_ylabel("Birth Rate Avg")

        plt.show()

cities = ['Seattle']


if __name__=="__main__":
    main()



