import numpy as np
import pandas as pd

import matplotlib.pyplot as plt
from matplotlib.ticker import FuncFormatter
import seaborn as sns

import statsmodels.api as sm
from scipy import stats

import metro as mt

def main():
    do_incomes()


def do_19301():

    from Table19301 import Table19301

    # Seaborn 
    sns.set_palette("deep", desat=.6)
    sns.set_context(rc={"figure.figsize": (8, 4)})
    
    for city in cities:

        mogo = mt.MetroMogo()
        df = mogo.get_df(city,tablecode="B19301")

        df = Table19301(df)

        #######################
        # KDE plot:
        #
        # per capita income

        f, ax1 = plt.subplots(1, 1, sharex=True, figsize=(8, 8))
        ax1.set_title(cities[0])

        colors = ["windows blue", "amber", "greyish", "faded green", "dusty purple"]
        xcp = sns.xkcd_palette(colors)

        # --------------
        # subplot 1

        xcode = 'PerCapitaIncome'
        xlabel=xcode

        df2 = df[df[xcode]>0]

        def thousands(x, pos):
            'The two args are the value and tick position'
            return '$%1.0fk' % (x*1e-3)

        fmt = FuncFormatter(thousands)
        ax1.set_xlim([0,120000])
        ax1.xaxis.set_major_formatter(fmt)
        sns.kdeplot(df[xcode], shade=True, color=xcp[0], ax=ax1)

        ax1.set_xlabel('Per Capita Income')
        ax1.set_ylabel('Probability Density')

        plt.show()

def do_25105():

    from Table25105 import Table25105

    # Seaborn 
    sns.set_palette("deep", desat=.6)
    sns.set_context(rc={"figure.figsize": (8, 4)})
    
    for city in cities:

        mogo = mt.MetroMogo()
        df = mogo.get_df(city,tablecode="B25070")

        df = Table25105(df)


        #######################
        # KDE plot:
        #
        # per capita income

        f, ax1 = plt.subplots(1, 1, sharex=True, figsize=(8, 8))
        ax1.set_title(cities[0])

        colors = ["windows blue", "amber", "greyish", "faded green", "dusty purple"]
        xcp = sns.xkcd_palette(colors)

        # -------------
        # subplot 1

        xcode = 'MedianMonthlyHousingCosts'
        xlabel=xcode

        sns.kdeplot(df[xcode], shade=True, color=xcp[3], ax=ax1)

        plt.show()


def do_incomescosts():

    from Table19301 import Table19301
    from Table25105 import Table25105

    # Seaborn 
    sns.set_palette("deep", desat=.6)
    sns.set_context(rc={"figure.figsize": (8, 4)})
    
    for city in cities:

        mogo = mt.MetroMogo()
        df = mogo.get_df(city,tablecode="B19301")

        df = Table19301(df)
        df = Table25105(df)


        #######################
        # KDE plot:
        #
        # per capita income

        f, ax1 = plt.subplots(1, 1, sharex=True, figsize=(8, 8))
        ax1.set_title(cities[0])

        colors = ["windows blue", "dusty purple", "greyish", "faded green", "amber"]
        xcp = sns.xkcd_palette(colors)

        # ------------------
        # subplot 1

        xcode = 'MedianMonthlyHousingCosts'
        xlabel=xcode
        sns.kdeplot(df[xcode]*12, shade=True, color=xcp[0], ax=ax1)

        xcode = 'PerCapitaIncome'
        xlabel=xcode
        sns.kdeplot(df[xcode], shade=True, color=xcp[1], ax=ax1)

        ax1.set_xlabel('Annual Housing Costs and Per Capita Income')
        ax1.set_ylabel('Probability Density')

        plt.show()


cities = ['Seattle']

if __name__=="__main__":
    main()



