from pymongo import MongoClient

import numpy as np
import pandas as pd


def Table13016(df):
    """
    B13016 : Women 15 to 50 Years Who Had a Birth in the Past 12 Months by Age
        B13016001 : Total:
            B13016002 : Women who had a birth in the past 12 months:
                B13016003 : 15 to 19 years old
                B13016004 : 20 to 24 years old
                B13016005 : 25 to 29 years old
                B13016006 : 30 to 34 years old
                B13016007 : 35 to 39 years old
                B13016008 : 40 to 44 years old
                B13016009 : 45 to 50 years old
            B13016010 : Women who did not have a birth in the past 12 months:
                B13016011 : 15 to 19 years old
                B13016012 : 20 to 24 years old
                B13016013 : 25 to 29 years old
                B13016014 : 30 to 34 years old
                B13016015 : 35 to 39 years old
                B13016016 : 40 to 44 years old
                B13016017 : 45 to 50 years old
    B13016universe : Women 15 to 50 Years
    B13016yr : 2013
    """

    total_fields = np.array(['B13016001',
                             'B13016002',
                             'B13016010'])

    #                        col1: had a birth
    #                                   col2: did not have a birth
    table_fields = np.array([['B13016003','B13016011'], # 15 to 19 years old 
                             ['B13016004','B13016012'], # 20 to 24 years old 
                             ['B13016005','B13016013'], # 25 to 29 years old 
                             ['B13016006','B13016014'], # 30 to 34 years old 
                             ['B13016007','B13016015'], # 35 to 39 years old 
                             ['B13016008','B13016016'], # 40 to 44 years old 
                             ['B13016009','B13016017']  # 45 to 50 years old 
                           ])

    tot   = df[total_fields[0]]
    btot  = df[total_fields[1]]
    nbtot = df[total_fields[2]]

    df['NoBirthRateAvg']   = nbtot/tot
    df['BirthRateAvg']   = btot/tot

    var = 0
    for k in range(table_fields.shape[0]):
        pi = df[table_fields[k,0]]/(df[table_fields[k,0]]+df[table_fields[k,1]])
        dev = 1 - df['BirthRateAvg']
        var += pi*pow(dev,2)

    df['BirthRateVariance'] = var

    return df

