from pymongo import MongoClient

import numpy as np
import pandas as pd

def Table17001(df):

    # Populate a numpy ndarray
    # with field names in correct positions

    # block 1 = below povery line
    #                   column 1: male 
    #                               column 2: female
    table_fields = np.array([[['B17001004', 'B17001018'],       # under 5
                              ['B17001005', 'B17001019'],       # 5
                              ['B17001006', 'B17001020'],       # 6-11
                              ['B17001007', 'B17001021'],       # 12-14
                              ['B17001008', 'B17001022'],       # 15
                              ['B17001009', 'B17001023'],       # 16-17
                              ['B17001010', 'B17001024'],       # 18-24
                              ['B17001011', 'B17001025'],       # 25-34
                              ['B17001012', 'B17001026'],       # 35-44
                              ['B17001013', 'B17001027'],       # 45-54
                              ['B17001014', 'B17001028'],       # 55-64
                              ['B17001015', 'B17001029'],       # 65-74
                              ['B17001016', 'B17001030']],      # 75
                      
                             [[ 'B17001033', 'B17001047'],
                              [ 'B17001034', 'B17001048'],
                              [ 'B17001035', 'B17001049'],
                              [ 'B17001036', 'B17001050'],
                              [ 'B17001037', 'B17001051'],
                              [ 'B17001038', 'B17001052'],
                              [ 'B17001039', 'B17001053'],
                              [ 'B17001040', 'B17001054'],
                              [ 'B17001041', 'B17001055'],
                              [ 'B17001042', 'B17001056'],
                              [ 'B17001043', 'B17001057'],
                              [ 'B17001044', 'B17001058'],
                              [ 'B17001045', 'B17001059']]])


    # -----------------------------
    # PDF:
    # Poverty Status by Gender 

    # Make a list of indices for column names:
    # M/F poor/not poor
    m_p  = []
    m_np = []
    f_p  = []
    f_np = []
    for k in range(table_fields.shape[1]):
        keys = table_fields[:,k,:]
        m_p.append( keys[0,0])
        m_np.append(keys[1,0])
        f_p.append( keys[0,1])
        f_np.append(keys[1,1])

    m_p_tot   = df[m_p].sum(axis=1)
    f_p_tot   = df[f_p].sum(axis=1)

    df['M_P_Tot']   = m_p_tot
    df['F_P_Tot']   = f_p_tot

    m_np_tot  = df[m_np].sum(axis=1)
    f_np_tot  = df[f_np].sum(axis=1)

    df['M_NP_Tot']   = m_np_tot
    df['F_NP_Tot']   = f_np_tot

    p_tot     = m_p_tot + f_p_tot 
    np_tot    = m_np_tot + f_np_tot

    df['P_Tot']   = p_tot
    df['NP_Tot']  = np_tot

    m_tot     = m_p_tot + m_np_tot
    f_tot     = f_p_tot + f_np_tot

    df['M_Tot']  = m_tot
    df['F_Tot']  = f_tot

    tot1      = p_tot + np_tot

    df['TotalPop'] = tot1

    df['M_P_PctM']   = m_p_tot/m_tot
    df['F_P_PctF']   = f_p_tot/f_tot

    df['M_P_Pct']   = m_p_tot/p_tot
    df['F_P_Pct']   = f_p_tot/p_tot

    df['M_NP_PctM']  = m_np_tot/m_tot
    df['F_NP_PctF']  = f_np_tot/f_tot

    df['M_NP_Pct']   = m_np_tot/np_tot
    df['F_NP_Pct']   = f_np_tot/np_tot

    df['P_Pct']     = p_tot/tot1
    df['NP_Pct']    = np_tot/tot1


    # -----------------------------
    # PDF:
    # Poverty Status by Age Groups 
    # 
    # pa = pre-adolescent < 13
    # juv = juvenile < 18
    # sr = senior > 65
    # 
    pam_p  = []
    pam_np = []
    paf_p  = []
    paf_np = []
    juvm_p  = []
    juvm_np = []
    juvf_p  = []
    juvf_np = []
    srm_p  = []
    srm_np = []
    srf_p  = []
    srf_np = []
    for k in range(table_fields.shape[1]):
        if k <= 2:
            keys = table_fields[:,k,:]
            pam_p.append( keys[0,0])
            pam_np.append(keys[1,0])
            paf_p.append( keys[0,1])
            paf_np.append(keys[1,1])
        if k > 2 and k <= 5:
            keys = table_fields[:,k,:]
            juvm_p.append( keys[0,0])
            juvm_np.append(keys[1,0])
            juvf_p.append( keys[0,1])
            juvf_np.append(keys[1,1])
        if k > 10:
            srm_p.append( keys[0,0])
            srm_np.append(keys[1,0])
            srf_p.append( keys[0,1])
            srf_np.append(keys[1,1])



    pam_p_tot   = df[pam_p].sum(axis=1)
    paf_p_tot   = df[paf_p].sum(axis=1)
    pam_np_tot  = df[pam_np].sum(axis=1)
    paf_np_tot  = df[paf_np].sum(axis=1)

    pap_tot     = pam_p_tot  + paf_p_tot 
    panp_tot    = pam_np_tot + paf_np_tot

    pam_tot     = pam_p_tot + pam_np_tot
    paf_tot     = paf_p_tot + paf_np_tot

    patot1      = pap_tot + panp_tot
    patot2      = pam_tot + paf_tot

    df['PAM_P_PctM']   = pam_p_tot/pam_tot
    df['PAF_P_PctF']   = paf_p_tot/paf_tot

    df['PAM_NP_PctM']  = pam_np_tot/pam_tot
    df['PAF_NP_PctF']  = paf_np_tot/paf_tot

    df['PAP_Pct']     = pap_tot/patot1
    df['PANP_Pct']    = panp_tot/patot1



    juvm_p_tot   = df[juvm_p].sum(axis=1)
    juvf_p_tot   = df[juvf_p].sum(axis=1)
    juvm_np_tot  = df[juvm_np].sum(axis=1)
    juvf_np_tot  = df[juvf_np].sum(axis=1)

    juvp_tot     = juvm_p_tot  + juvf_p_tot 
    juvnp_tot    = juvm_np_tot + juvf_np_tot

    juvm_tot     = juvm_p_tot + juvm_np_tot
    juvf_tot     = juvf_p_tot + juvf_np_tot

    juvtot1      = juvp_tot + juvnp_tot
    juvtot2      = juvm_tot + juvf_tot

    df['JuvM_P_PctM']   = juvm_p_tot/juvm_tot
    df['JuvF_P_PctF']   = juvf_p_tot/juvf_tot

    df['JuvM_NP_PctM']  = juvm_np_tot/juvm_tot
    df['JuvF_NP_PctF']  = juvf_np_tot/juvf_tot

    df['JuvP_Pct']     = juvp_tot/juvtot1
    df['JuvNP_Pct']    = juvnp_tot/juvtot1



    srm_p_tot   = df[srm_p].sum(axis=1)
    srf_p_tot   = df[srf_p].sum(axis=1)
    srm_np_tot  = df[srm_np].sum(axis=1)
    srf_np_tot  = df[srf_np].sum(axis=1)

    srp_tot     = srm_p_tot  + srf_p_tot 
    srnp_tot    = srm_np_tot + srf_np_tot

    srm_tot     = srm_p_tot + srm_np_tot
    srf_tot     = srf_p_tot + srf_np_tot

    srtot1      = srp_tot + srnp_tot
    srtot2      = srm_tot + srf_tot

    df['SrM_P_PctM']   = srm_p_tot/srm_tot
    df['SrF_P_PctF']   = srf_p_tot/srf_tot

    df['SrM_NP_PctM']  = srm_np_tot/srm_tot
    df['SrF_NP_PctF']  = srf_np_tot/srf_tot

    df['SrP_Pct']     = srp_tot/srtot1
    df['SrNP_Pct']    = srnp_tot/srtot1





    # --------------------
    # Pct of population in each poverty category
    # Pct of population in each age group
    # Pct of population in each gender



    # ---------------------
    # Avg poverty pct, 
    # marginal or overall


    # ---------------------
    # Variance in poverty pct,
    # marginal or overall





    # 
    # Pct of age group in poverty/not in poverty
    # under 5 
    # 5       
    # 6-11    
    # 12-14   
    # 15      
    # 16-17   
    # 18-24   
    # 25-34   
    # 35-44   
    # 45-54   
    # 55-64   
    # 65-74   
    # 75      






    #for k in df.iloc[0].keys():
    #    print k 

    #for k in df.iloc[0].keys():
    #    print k + " : " + str(df.iloc[0][k])


    df = df.dropna()

    return df



