from pymongo import MongoClient

import numpy as np
import pandas as pd



def Table25013(df):

    # Populate a numpy ndarray
    # with field names in correct positions

    """
    B25013 : Tenure by Educational Attainment of Householder
        B25013001 : Total:
            B25013002 : Owner-occupied housing units:
                B25013003 : Less than high school graduate
                B25013004 : High school graduate (including equivalency)
                B25013005 : Some college or associate's degree
                B25013006 : Bachelor's degree or higher
            B25013007 : Renter-occupied housing units:
                B25013008 : Less than high school graduate
                B25013009 : High school graduate (including equivalency)
                B25013010 : Some college or associate's degree
                B25013011 : Bachelor's degree or higher
    B25013universe : Occupied Housing Units
    B25013yr : 2013
    """


    # tenure by educ attainment
    total_fields = np.array(['B25013001',
                             'B25013002',
                             'B25013007'])

    #                        col1: house
    #                               col2: rent
    table_fields = np.array([['B25013003','B25070008'], # Less than high school graduate               
                             ['B25013004','B25070009'], # High school graduate (including equivalency) 
                             ['B25013005','B25070010'], # Some college or associate's degree           
                             ['B25013006','B25070011']  # Bachelor's degree or higher                  
                             ])

    tot_pop   = df[total_fields[0]]
    house_pop = df[total_fields[1]]
    rent_pop  = df[total_fields[2]]

    df['TotalPop'] = tot_pop
    df['HousePop'] = house_pop
    df['RentPop'] = rent_pop

    df['HousePct'] = house_pop/tot_pop
    df['RentPct'] = rent_pop/tot_pop


    for k in range(table_fields.shape[0]):

        hi = table_fields[k,0]
        ri = table_fields[k,1]

        lab = 'EdCat%d_HousePct'%(k+1)
        df[lab] = df[hi]/(df[hi]+df[ri])

        lab = 'EdCat%d_RentPct'%(k+1)
        df[lab] = df[ri]/(df[hi]+df[ri])


    df = df.fillna(0)

    return df


