from pymongo import MongoClient

import numpy as np
import pandas as pd



def Table25070(df):

    # Populate a numpy ndarray
    # with field names in correct positions

    """
    B25070 : Gross Rent as a Percentage of Household Income in the Past 12 Months
        B25070001 : Total:
            B25070002 : Less than 10.0 percent
            B25070003 : 10.0 to 14.9 percent
            B25070004 : 15.0 to 19.9 percent
            B25070005 : 20.0 to 24.9 percent
            B25070006 : 25.0 to 29.9 percent
            B25070007 : 30.0 to 34.9 percent
            B25070008 : 35.0 to 39.9 percent
            B25070009 : 40.0 to 49.9 percent
            B25070010 : 50.0 percent or more
            B25070011 : Not computed
    B25070universe : Renter-occupied Housing Units
    B25070yr : 2013
    """
    # rent as pct of income
    table_fields = np.array(['B25070002', # <10
                             'B25070003', # 10-15
                             'B25070004', # 15-20
                             'B25070005', # 20-25
                             'B25070006', # 25-30
                             'B25070007', # 30-35
                             'B25070008', # 35-40
                             'B25070009', # 40-50
                             'B25070010' # 50+
                             ])

    tot_pop = df[table_fields].sum(axis=1)

    df['TotalRenters'] = tot_pop 


    # ----------------------
    # Compute percentages

    labels = ["0-10","10-15","15-20","20-25","25-30","30-35","35-40","40-50","50+"]

    for i,(colname,collab) in enumerate(zip(table_fields,labels)):

        df["Rent_"+collab+"_Tot"] = df[colname]
        df["Rent_"+collab+"_Pct"] = df[colname]/df['TotalRenters']


    new_labels = ["0-10","10-20","20-30","30-40","40-50","50+"]
    old_labels = labels

    # aggregate columns
    perms = [0,1,1,2,2,3,3,4,5]

    oldlabels = {}
    for newlab in new_labels:
        oldlabels[newlab] = []
    for k,colname in enumerate(range(table_fields.shape[0])):
        p = perms[k]
        newlab = new_labels[p]
        oldlabels[newlab] += [colname]

    # sum aggregated columns
    for i,newlab in enumerate(new_labels):

        val = df[oldlabels[newlab]].sum(axis=1)
        pop = df['TotalRenters']

        df["NewRent_"+newlab+"_Tot"] = val
        df["NewRent_"+newlab+"_Pct"] = val/pop

    df = df.fillna(0)

    return df


