import numpy as np
import pandas as pd

import matplotlib.pyplot as plt
import seaborn as sns

import statsmodels.api as sm
from scipy import stats

import metro as mt

def main():
    do_15002()

def get_colors():

    p1 = ["windows blue",
          "dusty purple",
          "butterscotch",
          "caramel"]

    p2 = ["dusty red",
          "turtle green",
          "stormy blue",
          "dusty teal"]

    xcps = [sns.xkcd_palette(p1),
            sns.xkcd_palette(p2)]

    return xcps


def do_15002():

    from Table15002 import Table15002

    # Seaborn 
    sns.set_palette("deep", desat=.6)
    sns.set_context(rc={"figure.figsize": (8, 4)})



    #######################
    # Scatter plot "avg":
    #
    # average vs variance 
    # average vs gender imbalance
    
    avg_f, (avg_ax1, avg_ax2) = plt.subplots(1, 2, sharex=True, figsize=(14,6))
    


    #######################
    # Scatter plot "var":
    # 
    # variances vs averages
    # variances vs gender imbalance
    
    var_f, (var_ax1, var_ax2) = plt.subplots(1, 2, sharex=True, figsize=(14,6))


    avg_f.suptitle(", ".join(cities))
    var_f.suptitle(", ".join(cities))

    for ic,city in enumerate(cities):

        xcp = xcps[ic]

        mogo = mt.MetroMogo()
        df = mogo.get_df(city,tablecode="B15002")

        df = Table15002(df)

    
        #########
        # "avg"

        # ------------------------
        # Subplot 1
    
        xcode = 'AvgEd'
        xlabel=xcode

        ycode = 'VarEd'
        ylabel=ycode
        df2 = df[df[xcode]>0]
        sns.regplot(df2[xcode],df2[ycode], color=xcp[0], ax=avg_ax1, fit_reg=False, scatter_kws={'alpha':0.6}, label=city)
        avg_ax1.legend(loc="lower right")

        if ic>0:
            xlim = (min(min(df2[xcode]),avg_ax1.get_xlim()[0]),
                    max(max(df2[xcode]),avg_ax1.get_xlim()[1]))
            ylim = (min(min(df2[ycode]),avg_ax1.get_ylim()[0]),
                    max(max(df2[ycode]),avg_ax1.get_ylim()[1]))
        else:
            xlim = (min(df2[xcode]),
                    max(df2[xcode]))
            ylim = (min(df2[ycode]),
                    max(df2[ycode]))
    
        avg_ax1.set_xlim(xlim)
        avg_ax1.set_ylim(ylim)
    
        avg_ax1.set_xlabel(xlabel)
        avg_ax1.set_ylabel(ylabel)


        # ------------------------
        # Subplot 2
    
        xcode = 'AvgEd'
        xlabel=xcode
        ycode = 'EdGenderImbalance'
        ylabel=ycode
        df2 = df[df[xcode]>0]
        sns.regplot(df2[xcode],df2[ycode], color=xcp[1], ax=avg_ax2, fit_reg=False, scatter_kws={'alpha':0.6}, label=city)
        avg_ax2.legend(loc="upper right")
    
        if ic>0:
            xlim = (min(min(df2[xcode]),avg_ax2.get_xlim()[0]),
                    max(max(df2[xcode]),avg_ax2.get_xlim()[1]))
            ylim = (min(min(df2[ycode]),avg_ax2.get_ylim()[0]),
                    max(max(df2[ycode]),avg_ax2.get_ylim()[1]))
        else:
            xlim = (min(df2[xcode]),
                    max(df2[xcode]))
            ylim = (min(df2[ycode]),
                    max(df2[ycode]))

        avg_ax2.set_xlim(xlim)
        avg_ax2.set_ylim(ylim)
    
        avg_ax2.set_xlabel(xlabel)
        avg_ax2.set_ylabel(ylabel)



    

        ###########
        # "var"

        # ------------------------
        # Subplot 1
    
        xcode = 'VarEd'
        xlabel=xcode
        ycode = 'AvgEd'
        ylabel=ycode
        df2 = df[df[xcode]>0]
        sns.regplot(df2[xcode],df2[ycode], color=xcp[2], ax=var_ax1, fit_reg=False, scatter_kws={'alpha':0.6}, label=city)
        var_ax1.legend(loc="lower right")
    
        if ic>0:
            xlim = (min(min(df2[xcode]),var_ax1.get_xlim()[0]),
                    max(max(df2[xcode]),var_ax1.get_xlim()[1]))
            ylim = (min(min(df2[ycode]),var_ax1.get_ylim()[0]),
                    max(max(df2[ycode]),var_ax1.get_ylim()[1]))
        else:
            xlim = (min(df2[xcode]),
                    max(df2[xcode]))
            ylim = (min(df2[ycode]),
                    max(df2[ycode]))

        var_ax1.set_xlim(xlim)
        var_ax1.set_ylim(ylim)


        # ------------------------
        # Subplot 2
    
        xcode = 'VarEd'
        xlabel=xcode
        ycode = 'EdGenderImbalance'
        ylabel=ycode
        df2 = df[df[xcode]>0]
        sns.regplot(df2[xcode],df2[ycode], color=xcp[3], ax=var_ax2, fit_reg=False, scatter_kws={'alpha':0.6}, label=city)
        var_ax2.legend(loc="upper right")

        if ic>0:
            xlim = (min(min(df2[xcode]),var_ax2.get_xlim()[0]),
                    max(max(df2[xcode]),var_ax2.get_xlim()[1]))
            ylim = (min(min(df2[ycode]),var_ax2.get_ylim()[0]),
                    max(max(df2[ycode]),var_ax2.get_ylim()[1]))
        else:
            xlim = (min(df2[xcode]),
                    max(df2[xcode]))
            ylim = (min(df2[ycode]),
                    max(df2[ycode]))

        var_ax2.set_xlim(xlim)
        var_ax2.set_ylim(ylim)


    plt.show()


xcps = get_colors()
cities = ['San Francisco','Seattle']

if __name__=="__main__":
    main()


