import numpy as np
import pandas as pd

import matplotlib.pyplot as plt
import seaborn as sns

import statsmodels.api as sm
from scipy import stats

import metro as mt

def get_colors():

    p1 = ["windows blue",
          "dusty purple",
          "butterscotch",
          "caramel"]

    p2 = ["dusty red",
          "turtle green",
          "stormy blue",
          "dusty teal"]

    xcps = [sns.xkcd_palette(p1),
            sns.xkcd_palette(p2)]

    return xcps


def do_17001(do_plots):

    from Table17001 import Table17001

    # Seaborn 
    sns.set_palette("deep", desat=.6)
    sns.set_context(rc={"figure.figsize": (8, 4)})



    #######################
    # Scatter plot "pov"
    # 
    # poverty rate total
    # poverty rate seniors
    if 'pov' in do_plots:
        pov_f, (pov_ax1, pov_ax2) = plt.subplots(2, 1, sharex=False, figsize=(8,8))


    #######################
    # Plot "pct":
    # Percent of people in poverty
    # overall, and by gender
    if 'pct' in do_plots:
        pct_f, (pct_ax1, pct_ax2) = plt.subplots(2, 1, sharex=False, figsize=(8,8))


    #######################
    # Plot "pad":
    # Pre-adolescent poverty levels 
    # (overall and by gender)
    if 'pad' in do_plots:
        pad_f, (pad_ax1, pad_ax2) = plt.subplots(2, 1, sharex=False, figsize=(8,8))


    #######################
    # Plot "sr":
    # Senior poverty levels 
    # (overall and by gender)
    if 'sr' in do_plots:
        sr_f, (sr_ax1, sr_ax2) = plt.subplots(2, 1, sharex=False, figsize=(8,8))


    title = ", ".join(cities)
    if 'pov' in do_plots:
        pov_f.suptitle(title)
    if 'pct' in do_plots:
        pct_f.suptitle(title)
    if 'pad' in do_plots:
        pad_f.suptitle(title)
    if 'sr' in do_plots:
        sr_f.suptitle(title)


    for ic,city in enumerate(cities):

        xcp = xcps[ic]

        mogo = mt.MetroMogo()
        df = mogo.get_df(city,tablecode="B17001")

        df = Table17001(df)

    
        if 'pov' in do_plots:

            #########
            # "pov"

            # ------------------------
            # Subplot 1
    
            #xcode = 'TotalPop'
            #xlabel=xcode
            #ycode = 'M_P_PctM'
            #ylabel=ycode
            #sns.regplot(df[xcode],df[ycode], color=xcp[0], ax=pov_ax1, fit_reg=False, label=city)
    
            #xcode = 'TotalPop'
            #xlabel=xcode
            #ycode = 'F_P_PctF'
            #ylabel=ycode
            #sns.regplot(df[xcode],df[ycode], color=xcp[1], ax=pov_ax1, fit_reg=False, label=city)
    
            xcode = 'TotalPop'
            xlabel=xcode
            ycode = 'P_Pct'
            ylabel=ycode
            sns.regplot(df[xcode],df[ycode], color=xcp[0], ax=pov_ax1, fit_reg=False, label=city)
            pov_ax1.legend(loc="upper right")
    
            xlim = (min(df[xcode]),
                    max(df[xcode]))
            ylim = (min(df[ycode]),
                    max(df[ycode]))
    
            pov_ax1.set_xlim(xlim)
            pov_ax1.set_ylim(ylim)
    
            pov_ax1.set_xlabel(xlabel)
            pov_ax1.set_ylabel('Pct Population Below Pov Line')

            # ------------------------
            # Subplot 2
    
            #xcode = 'TotalPop'
            #xlabel=xcode
            #ycode = 'SrM_P_PctM'
            #ylabel=ycode
            #sns.regplot(df[xcode],df[ycode], color=xcp[2], ax=pov_ax2, fit_reg=False, label=city)
    
            #xcode = 'TotalPop'
            #xlabel=xcode
            #ycode = 'SrF_P_PctF'
            #ylabel=ycode
            #sns.regplot(df[xcode],df[ycode], color=xcp[1], ax=pov_ax2, fit_reg=False, label=city)

            xcode = 'TotalPop'
            xlabel=xcode
            ycode = 'SrP_Pct'
            ylabel=ycode
            sns.regplot(df[xcode],df[ycode], color=xcp[1], ax=pov_ax2, fit_reg=False, label=city)
    
            pov_ax2.legend(loc="upper right")
    
            xlim = (min(df[xcode]),
                    max(df[xcode]))
            ylim = (min(df[ycode]),
                    max(df[ycode]))
    
            pov_ax2.set_xlim(xlim)
            pov_ax2.set_ylim(ylim)
    
            pov_ax2.set_xlabel(xlabel)
            pov_ax2.set_ylabel('Pct Seniors Below Pov Line')


    

        if 'pct' in do_plots:

            ###########
            # "pct"

            # ------------------------
            # Subplot 1
    
            sns.kdeplot(df['P_Pct'],    shade=False, color=xcp[3], ax=pct_ax1, label=city)
            sns.kdeplot(df['M_P_PctM'], shade=False, color=xcp[2], ax=pct_ax2, label="M "+city)
            sns.kdeplot(df['F_P_PctF'], shade=False, color=xcp[1], ax=pct_ax2, label="F "+city)

            pct_ax1.set_xlim([0,0.6])
            pct_ax2.set_xlim([0,0.6])

            pct_ax1.set_xlabel('Pct Population Below Pov. Line')
            pct_ax1.set_ylabel('Probability Density')

            pct_ax2.set_xlabel('Pct Male/Female Population Below Pov. Line')
            pct_ax2.set_ylabel('Probability Density')


        if 'pad' in do_plots:


            #######################
            # "pad"
    
            xlim = 0.50
            ylim = 5
    
            sns.kdeplot( df['PAP_Pct'],    shade=False, color=xcp[3], ax=pad_ax1, label=city)
            sns.kdeplot( df['PAM_P_PctM'], shade=False, color=xcp[2], ax=pad_ax2, label=city)
            sns.kdeplot( df['PAF_P_PctF'], shade=False, color=xcp[1], ax=pad_ax2, label=city)
            
            pad_ax1.set_xlim([0,0.6])
            pad_ax2.set_xlim([0,0.6])

            pad_ax1.set_xlabel('Pct Pre-Adolescents Below Pov. Line')
            pad_ax1.set_ylabel('Probability Density')

            pad_ax2.set_xlabel('Pct Male/Female Pre-Adolescents Below Pov. Line')
            pad_ax2.set_ylabel('Probability Density')


        if 'sr' in do_plots:


            #######################
            # "sr"

            sns.kdeplot( df['SrP_Pct'],    shade=False, color=xcp[3], ax=sr_ax1, label=city)
            sns.kdeplot( df['SrM_P_PctM'], shade=False, color=xcp[2], ax=sr_ax2, label=city)
            sns.kdeplot( df['SrF_P_PctF'], shade=False, color=xcp[1], ax=sr_ax2, label=city)
    
            sr_ax1.set_xlim([0,1])
            sr_ax2.set_xlim([0,1])
    
            sr_ax1.set_xlabel('Pct Seniors Below Pov. Line')
            sr_ax1.set_ylabel('Probability Density')

            sr_ax2.set_xlabel('Pct Male/Female Seniors Below Pov. Line')
            sr_ax2.set_ylabel('Probability Density')


    plt.show()


xcps = get_colors()
cities = ['San Francisco','Seattle']

if __name__=="__main__":
    do_17001()


