import metro as mt

from timeit import default_timer as timer
import json
import urllib2

import numpy as np

import re
import os
import subprocess
import logging

from collections import OrderedDict
from pymongo import MongoClient



# =============================================================
# ============= populate geometry table =======================
# =============================================================

def populate_geometry_table():

    mm = mt.MetroMogo()

    cities = ['Seattle','Houston','Dallas','Chicago','New York','Los Angeles','San Francisco']

    metroCodes = {}
    for city in cities:
        metroCodes[city] = mt.CBSACode(city)[0]

    for ii,(metro_name,metro_id) in enumerate(zip(metroCodes.keys(),metroCodes.values())):
        mm.add_geometry(metro_id,metro_name)

    logging.info("Done populating geometry table.")





# =============================================================
# ============= populate properties table =====================
# =============================================================



def populate_properties_table():

    mm = mt.MetroMogo()

    tables = ['B15002', # education levels
              'B17001', # gender by povery status
              'B25105', # median monthly housing costs
              'B08126', # means of xportation by industry
              'B19301', # per capita income
              'B25070', # rent as pct of household income
              'B25013', # housing tenure by educational attainment
              'B13016', # Women 15 to 50 Years Who Had a Birth in the Past 12 Months by Age
              'B19013', # Median Household Income in the Past 12 Months (In 2013 Inflation-adjusted Dollars)
              'B19125', # Median Family Income in the Past 12 Months (In 2013 Inflation-adjusted Dollars) by Presence of Own Children Under 18 Years
              'B23025'] # Employment Status for the Population 16 Years and Over

    cities = ['Seattle','Houston','Dallas','Chicago','New York','Los Angeles','San Francisco']

    metroCodes = {}
    for city in cities:
        metroCodes[city] = mt.CBSACode(city)[0]

    for ii,(metro_name,metro_id) in enumerate(zip(metroCodes.keys(),metroCodes.values())):
        for tablecode in tables:
            mm.add_property(tablecode,metro_id,metro_name)

    logging.info("Done populating properties table.")


# =============================================================
# ============= driver routine ================================
# =============================================================


if __name__=="__main__":
    populate_geometry_table()
    populate_properties_table()


