from timeit import default_timer as timer
import json
import urllib2

import numpy as np

import re
import os
import subprocess

from collections import OrderedDict
from pymongo import MongoClient

from constants import DBNAME
from Lumberjack import *



class Mogo(object):
    """
    Simple wrapper to a MongoDB client/database
    """
    def __init__(self):
        self.client = MongoClient()
        self.make_db()
        self.make_collections()

        # Census Reporter API:
        # returns GeoJSON 
        self.geo_api_url   = "http://api.censusreporter.org/1.0/geo/show/tiger2013?geo_ids=GEOID"
        self.table_api_url = "http://api.censusreporter.org/1.0/data/show/latest?table_ids=TABLEID&geo_ids=GEOID"

        # from http://www.census.gov/prod/cen2010/doc/sf1.pdf 
        # page 115
        # 
        # 050 = State-County
        # 140 = State-County-Census Tract
        # 310 = Metropolitan statistical area
        # 500 = State-Congressional District
        # 860 = Zip code
        # 
        self.county_level = "050"
        self.censustract_level = "140" 
        self.metro_level = "310"
        self.congressional_level = "500"
        self.zipcode_level = "860"

    ###################
    # Databases

    def make_db(self):
        self.db = self.client[DBNAME]

    def drop_db(self):
        start = timer()
        self.client.drop_database(DBNAME)
        endd = timer()
        logging.info("Drop database took %0.3f seconds"%(endd-start))
        return 1

    ###################
    # Collections

    def make_collections(self):
        self.Geometry = self.db['Geometry']
        self.Properties = self.db['Properties']

        self.GeometryMeta = self.db['GeometryMeta']
        self.PropertiesMeta = self.db['PropertiesMeta']


    def drop_table(self,collection):
        start = timer()
        self.client.drop_collection(collection)
        endd = timer()
        logging.info("Drop collection %s took %0.3f seconds"%(collection,endd-start))
        return 1

    def drop_geometry_table(self):
        start = timer()
        self.drop_table('Geometry')
    
    def drop_geometry_meta_table(self):
        start = timer()
        self.drop_table('GeometryMeta')
    
    def drop_properties_table(self):
        start = timer()
        self.drop_table('Properties')
    
    def drop_properties_meta_table(self):
        start = timer()
        self.drop_table('PropertiesMeta')

    def insert_geometry(self,payload):
        nrecords = len(payload)
        start_ins = timer()
        my_id = self.Geometry.insert(payload)
        end_ins = timer()
        logging.info("Geometry table: Calling insert on %d records took %0.3f seconds"%(nrecords,end_ins-start_ins))
        return my_id

    def insert_properties(self,payload):
        nrecords = len(payload)
        start_ins = timer()
        my_id = self.Properties.insert(payload)
        end_ins = timer()
        logging.info("Properties table: Calling insert on %d records took %0.3f seconds"%(nrecords,end_ins-start_ins))
        return my_id

    def insert_geometry_meta(self,payload):
        nrecords = len(payload)
        start_ins = timer()
        my_id = self.GeometryMeta.insert(payload)
        end_ins = timer()
        logging.info("Geometry meta table: Calling insert on %d records took %0.3f seconds"%(nrecords,end_ins-start_ins))
        return my_id

    def insert_properties_meta(self,payload):
        nrecords = len(payload)
        start_ins = timer()
        my_id = self.PropertiesMeta.insert(payload)
        end_ins = timer()
        logging.info("Properties meta table: Calling insert on %d records took %0.3f seconds"%(nrecords,end_ins-start_ins))
        return my_id


